#
# spec file for package python-python-whois
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-python-whois
Version:        0.8.0
Release:        2.1
Summary:        Whois querying and parsing of domain registration information
License:        MIT
URL:            https://bitbucket.org/richardpenman/pywhois
Source:         https://files.pythonhosted.org/packages/source/p/python-whois/python-whois-%{version}.tar.gz
Patch0:         remove-future-requirement.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module simplejson}
# /SECTION
BuildRequires:  fdupes
Suggests:       python-python-dateutil
BuildArch:      noarch
%python_subpackages

%description
A simple importable Python module which will produce parsed WHOIS data for a given domain.
Able to extract data for all the popular TLDs (com, org, net, ...)
Query a WHOIS server directly instead of going through an intermediate web service like many others do.

%prep
%autosetup -p1 -n python-whois-%{version}
# requires internet connection:
rm test/test_query.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_ipv4 test_ipv6 - online check
# test_il_parse - online check
%pytest -k 'not (test_ipv4 or test_ipv6 or test_il_parse)'

%files %{python_files}
%doc README.rst
%{python_sitelib}/whois
%{python_sitelib}/python_whois-%{version}.dist-info

%changelog
* Tue Sep 12 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch remove-future-requirement.patch, remove future requirement
- Switch to autosetup and pyproject macros
- Stop using greedy globs in %%files
* Tue Aug  9 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to 0.8.0:
  - no changelog available
- disable failing Python2 build.
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.2:
  * no changelog available
* Fri May  3 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.7.1:
  * no changelog available
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Apr 29 2018 sebix+novell.com@sebix.at
- update to version 0.7.0:
  * support for .lu, cz
  * fix for .eu
* Wed Mar 21 2018 sebix+novell.com@sebix.at
- update typo version 0.6.9:
  * fix .me
- update typo version 0.6.8:
  * support for .cat, .ie, .space, .nz
  * dealing with multiple dates improved
  * fixes for Python 3
* Thu Dec  7 2017 sebix+novell.com@sebix.at
- initial package for version 0.6.7
